<?php
/**
 * Agreeme checkboxes for WooCommerce - Frontend Class
 *
 * @version 1.0.0
 * @since   1.0.0
 * @author  Amin Yasser.
 */
if (!defined('ABSPATH')) exit; // Exit if accessed directly
if (!class_exists('agrwc_Frontend')):
    class agrwc_Frontend {
        /**
         * Constructor.
         *
         * @version 1.4.0
         * @since   1.0.0
         */
        public $sdata = array();
        function __construct() {
            //check if enabled.. if not skip frontend...
            $enabled = get_option('agrwc_enabled');
            if (!$enabled || $enabled == "no") return false;
            if (!session_id()) {
                session_start();
            }
            add_action('woocommerce_before_add_to_cart_button', array($this, 'addto_product_page'), PHP_INT_MAX);
            add_filter('woocommerce_add_to_cart_validation', array($this, 'addto_cart_validation'), PHP_INT_MAX);
            add_action('woocommerce_cart_totals_after_order_total', array($this, 'addto_cart_page'), PHP_INT_MAX);
            add_action('woocommerce_after_checkout_validation', array($this, 'validate_checkout'), PHP_INT_MAX, 2);
            add_action('woocommerce_after_order_notes', array($this, 'addto_checkout_page'), PHP_INT_MAX);
            add_action('woocommerce_thankyou', array($this, 'order_completed'), PHP_INT_MAX);
            add_action('woocommerce_checkout_update_order_meta', array($this, 'update_agree_checkbox_fields_order_meta'));
            add_action('woocommerce_cart_calculate_fees', array($this, 'add_fees'), PHP_INT_MAX);
			add_action('wp_ajax_agrwc_post', array($this, 'agrwc_post'));
            add_action('wp_ajax_nopriv_agrwc_post', array($this, 'agrwc_post'));
            add_action('wp_footer', array($this, 'load_jsscripts'));
            ///	$this->load_jsscripts();
            
        }
        /**
         * Submit checkbox data in cart page, Proceed to Checkout button link click : ajax request.
         *
         * @todo: may need validations for required checkboxes
         */
        public function order_completed($order_id) {
            $_SESSION['agrwc'] = '';
            unset($_SESSION['agrwc']);
        }
        public function agrwc_post() {
            if (isset($_POST['action']) == 'agrwc_post') {
                $cbxs = AGRWC_CBX::get_cbxs();
                //loop through all...
                foreach ($cbxs as $id => $cbx) {
                    if (isset($_POST[$id])) unset($_SESSION['agrwc'][$id]);
                    if ($_POST[$id]) {
                        $_SESSION['agrwc'][$id] = (int)$_POST[$id]; //checkbox if checked should be 1 
                    }
                }
                echo json_encode(array("success" => "1"));
                die();
            }
        }
        public function validate_checkout($data, $errors) {
            $passed = true;
            //get the default alert message..
            $alertmsg = get_option('agrwc_alertmsg');
            //loop through all required applicable checkboxes...
            //get the checkboxes as array of cbx objects
            $cbxs = AGRWC_CBX::get_cbxs();
            //loop through all...
            foreach ($cbxs as $id => $cbx) {
                //get location of each...and proceed further if matches
                $location_arr = $cbx->get_locations();
                if (in_array(3, $location_arr)) //product page addtocart button
                {
                    //get the product id match if not return...
                    $l_products = $cbx->get_limit_products();
                    if ($cbx->get_reqalert()) $alertmsg = $cbx->get_reqalert();
                    //$l_products=	explode(",",$cbx->get_limit_products());
                    // Getting cart product ids
                    $match_product = false;
                    if (is_array($l_products) && count($l_products)) {
                        foreach (WC()->cart->get_cart() as $cart_item_key => $values) {
                            if (in_array($values['product_id'], $l_products)) {
                                $match_product = true;
                            }
                        }
                    } else $match_product = true;
                    if (($match_product) && ($cbx->get_required() == 'yes') && !isset($_REQUEST[$id])) {
                        $errors->add('notes', $alertmsg);
                        $passed = false;
                    }
                    $_SESSION['agrwc'][$id] = (int)$_REQUEST[$id]; //store in session.
                    
                }
            }
            return $passed;
        }
        public function load_jsscripts() {
            $settings = array();
            //get the general options
            wp_enqueue_script('agrwc-jsscript', /* Handle/Name */
            AGR_WC::plugin_url() . '/js/agrwc-cbx.js', /* Path to the plugin/assets folder */
            //array('jquery', 'xml2json', 'json2xml'), /* Script Dependencies */
            array('jquery'), /* Script Dependencies */
            null, /* null is any version, but could be the specific version of jquery if required */
            true
            /* if true=add to footer, false=add to header */
            );
            $settings = $this->sdata;
            //get these options
            $settings['selFTags'] = get_option('agrwc_formclasses');
            $settings['selTags'] = get_option('agrwc_buttonclasses');
            $settings['alertText'] = get_option('agrwc_alertmsg');
            $settings['ajURL'] = admin_url('admin-ajax.php');
            wp_localize_script('agrwc-jsscript', 'AGRWC_VARS', $settings);
        }
        public function addto_cart_validation() {
            $passed = true;
            //loop through all required applicable checkboxes...
            //get the checkboxes as array of cbx objects
            $cbxs = AGRWC_CBX::get_cbxs();
            //loop through all...
            foreach ($cbxs as $id => $cbx) {
                //get location of each...and proceed further if matches
                $location_arr = $cbx->get_locations();
                if (in_array(1, $location_arr)) //product page addtocart button
                {
                    //get the product id match if not return...
                    $l_products = $cbx->get_limit_products();
                    //$l_products=	explode(",",$cbx->get_limit_products());
                    // Getting cart product ids
                    $match_product = false;
                    if (is_array($l_products) && count($l_products)) {
                        if (in_array($_REQUEST['add-to-cart'], $l_products)) {
                            if (($cbx->get_required() == 'yes') && !isset($_REQUEST[$id])) {
                                //wc_add_notice( __( 'Some required fields are missing', 'woocommerce' ), 'error' );
                                
                            }
                        }
                    }
                    if (isset($_REQUEST[$id]) && $_REQUEST['add-to-cart']) $_SESSION['agrwc'][$id] = (int)$_REQUEST[$id]; //store in session.
                    
                }
            }
            return $passed;
        }
        public function addto_product_page() {
            //get the checkboxes as array of cbx objects
            $cbxs = AGRWC_CBX::get_cbxs();
            //loop through all...
            foreach ($cbxs as $id => $cbx) {
                //get location of each...and proceed further if matches
                $location_arr = $cbx->get_locations();
                if (in_array(1, $location_arr)) //product page addtocart button
                {
                    //get the product id match if not return...
                    global $product;
                    $pid = $product->get_id();
                    $catidsarr = $product->get_category_ids();
                    $catids = array();
                    $l_products = $cbx->get_limit_products();
                    $l_cats = $cbx->get_limit_categories();
                    foreach ($catidsarr as $cid) {
                        $cc = get_term_by('id', $cid, 'product_cat', 'ARRAY_A');
                        if (isset($cc['slug'])) $catids[] = $cc['slug'];
                    }
                    $match_product = true;
                    //$l_products=	explode(",",$cbx->get_limit_products());
                    // Getting cart product ids
                    if (is_array($l_products) && count($l_products)) {
                        $match_product = false;
                        //get the current product id...in product page..
                        if (in_array($pid, $l_products)) $match_product = true;
                    }
                    if (is_array($l_cats) && count($l_cats)) {
                        $match_product = false;
                        foreach ($catids as $cid) {
                            //get the current product id...in product page..
                            if (in_array($cid, $l_cats)) {
                                $match_product = true;
                                break;
                            }
                        }
                    }
                    if ($cbx->get_required() == 'yes') {
                        $req = true;
                        $reqclass = " required ";
                    } else {
                        $req = false;
                        $reqclass = '';
                    };
                    if (isset($_SESSION[$id])) $checked = 1;
                    else $checked = 0;
                    if ($match_product) {
                        woocommerce_form_field($id, array('type' => 'checkbox', 'class' => array('form-row privacy', $reqclass), 'label_class' => array('woocommerce-form__label checkbox'), 'input_class' => array('woocommerce-form__input woocommerce-form__input-checkbox input-checkbox agrwc-cbx', $reqclass), 'required' => $req, 'label' => $cbx->get_label(),), $checked);
                        $this->sdata[$id] = esc_js($cbx->get_reqalert());
                    }
                }
            }
        }
        public function addto_cart_page() {
            //get the checkboxes as array of cbx objects
            $cbxs = AGRWC_CBX::get_cbxs();
            //loop through all the checkboxes...
            foreach ($cbxs as $id => $cbx) {
                //get location of each...and proceed further if matches
                $location_arr = $cbx->get_locations();
                if (in_array(2, $location_arr)) //product page addtocart button
                {
                    $l_products = $cbx->get_limit_products();
                    $l_cats = $cbx->get_limit_categories();
                    //$l_products=	explode(",",$cbx->get_limit_products());
                    // Getting cart product ids
                    $match_product = true;
                    //Validate for limiting to specific products in cart
                    if (is_array($l_products) && count($l_products)) {
                        $match_product = false;
                        $products = array();
                        foreach (WC()->cart->get_cart() as $cart_item_key => $values) {
                            if (in_array($values['product_id'], $l_products)) {
                                $match_product = true;
                                break;
                            }
                        }
                    }
                    //Validate for limiting to specific products with specific cats in cart
                    if (is_array($l_cats) && count($l_cats)) {
                        $match_product = false;
                        foreach (WC()->cart->get_cart() as $cart_item_key => $values) {
                            if (has_term($l_cats, 'product_cat', $values['product_id'])) {
                                $match_product = true;
                                break;
                            }
                        }
                    }
                    //if order total condition added, validate that also..
                    $l_ordertotal = $cbx->get_limit_ordertotal();
                    if ($l_ordertotal) {
                        $conditionx = $cbx->get_conditionx();
                        $match_product = false;
                        $ordertotal = WC()->cart->get_cart_contents_total();
                        switch ($conditionx) {
                            case "<":
                                if ($ordertotal < $l_ordertotal) $match_product = true;
                                break;
                            case ">":
                                if ($ordertotal < $l_ordertotal) $match_product = true;
                                break;
                            }
                        }
                        if ($match_product) {
                            if ($cbx->get_required() == 'yes') {
                                $req = true;
                                $reqclass = " required ";
                            } else {
                                $req = false;
                                $reqclass = '';
                            };
                            if (isset($_SESSION[$id])) $checked = 1;
                            else $checked = 0;
                            woocommerce_form_field($id, array('type' => 'checkbox', 'class' => array('form-row privacy', $reqclass), 'label_class' => array('woocommerce-form__label checkbox'), 'input_class' => array('woocommerce-form__input woocommerce-form__input-checkbox input-checkbox agrwc-cbx', $reqclass), 'required' => $req, 'label' => $cbx->get_label(),), $checked);
                            $this->sdata[$id] = esc_js($cbx->get_reqalert());
                        }
                    }
                }
        }
        public function addto_checkout_page() {
            //get the checkboxes as array of cbx objects
            $cbxs = AGRWC_CBX::get_cbxs();
            //loop through all...
            foreach ($cbxs as $id => $cbx) {
                //get location of each...and proceed further if matches
                $location_arr = $cbx->get_locations();
                if (in_array(3, $location_arr)) //product page addtocart button
                {
                    //get the product id match if not return...
                    //get the product id match if not return...
                    $l_products = $cbx->get_limit_products();
                    //$l_products=	explode(",",$cbx->get_limit_products());
                    // Getting cart product ids
                    $match_product = true;
                    if (is_array($l_products) && count($l_products)) {
                        $match_product = false;
                        foreach (WC()->cart->get_cart() as $cart_item_key => $values) {
                            if (in_array($values['product_id'], $l_products)) $match_product = true;
                        }
                    }
                    //order total condition added, validate that also..
                    $l_ordertotal = $cbx->get_limit_ordertotal();
                    if ($l_ordertotal) {
                        $conditionx = $cbx->get_conditionx();
                        $match_product = false;
                        $ordertotal = WC()->cart->get_cart_contents_total();
                        switch ($conditionx) {
                            case "<":
                                if ($ordertotal < $l_ordertotal) $match_product = true;
                                break;
                            case ">":
                                if ($ordertotal < $l_ordertotal) $match_product = true;
                                break;
                            }
                        }
                        if ($match_product) {
                            if ($cbx->get_required() == 'yes') {
                                $req = true;
                                $reqclass = " required ";
                            } else {
                                $req = false;
                                $reqclass = '';
                            };
                            if (isset($_SESSION[$id])) $checked = 1;
                            else $checked = 0;
                            woocommerce_form_field($id, array('type' => 'checkbox', 'class' => array('form-row privacy', $reqclass), 'label_class' => array('woocommerce-form__label checkbox'), 'input_class' => array('woocommerce-form__input woocommerce-form__input-checkbox input-checkbox agrwc-cbx', $reqclass), 'required' => $req, 'label' => $cbx->get_label(),), $checked);
                            $this->sdata[$id] = esc_js($cbx->get_reqalert());
                        }
                    }
                }
        }
        /**
         * add_fees.
         *
         * @version 1.1.0
         * For future versions
         *
         */
        public function add_fees($cart) {
            //coming soon...
            $fees_to_add = array();
            //get the checkboxes as array of cbx objects
            $cbxs = AGRWC_CBX::get_cbxs();
            //loop through all...
            foreach ($cbxs as $id => $cbx) {
                //get location of each...and proceed further if matches
                $location_arr = $cbx->get_locations();
                $fee_value = $cbx->get_add_fee();
                if ((in_array(3, $location_arr) || in_array(1, $location_arr) || in_array(2, $location_arr)) && $fee_value && isset($_SESSION['agrwc'][$id]) && $_SESSION['agrwc'][$id]) //add fee only works from checkout page..
                {
                    $fee_title = $cbx->get_fee_text();
                    // Adding fee
                    $fees_to_add[] = array('name' => $fee_title, 'amount' => $fee_value, 'taxable' => (isset($taxable) ? ('yes' === $taxable) : true), 'tax_class' => 'standard',);
                }
            }
            // Add fees
            if (!empty($fees_to_add)) {
                foreach ($fees_to_add as $fee_to_add) {
                    $cart->add_fee($fee_to_add['name'], $fee_to_add['amount'], $fee_to_add['taxable'], $fee_to_add['tax_class']);
                }
            }
        }
        /**
         * update_custom_checkout_fields_order_meta.
         *
         * @version 1.0.0
         * @since   1.0.0
         * @todo
         */
        function update_agree_checkbox_fields_order_meta($order_id) {
            $fields_data = array();
            $val_arr[0] = AGRWC_NO;
            $val_arr[1] = AGRWC_YES;
            //get the checkboxes as array of cbx objects
            $cbxs = AGRWC_CBX::get_cbxs();
            $type = 'checkbox';
            $section = 'billing';
            //loop through all...
            $ix = 0;
            foreach ($cbxs as $id => $cbx) {
                $ix++;
                if (isset($_SESSION['agrwc'][$id])) {
                    update_post_meta($order_id, '_agrwc_' . $id, $cbx->get_label() . " - " . $val_arr[(int)$_SESSION['agrwc'][$id]]);
                }
            }
        }
    }
endif;
return new agrwc_Frontend();
